@@ -306,11 +306,12 @@ impl<S, R, E, H, C> SqsService<S, R, E, H, C>
             let sqs_completion_handler = self.sqs_completion_handler.clone();
             let handle = std::thread::spawn(move || {
                 let unparsed_event = event.body.expect("SqsMessage missing body");
+                let receipt_handle = event.receipt_handle.expect("receipt_handle");
 
                 let event = retriever.retrieve_event(unparsed_event)?;
 
                 handler.handle_event(event)?;
-                sqs_completion_handler.complete_message("receipt".into())?;
+                sqs_completion_handler.complete_message(receipt_handle)?;
 
                 Ok(())
             });
